Estimates which intervals in a dataset are fundamental intervals, i.e. an interval not containing a missed arrival observation
fundamental(x, conf.level = 0.9)object inheriting from class intRvals, usually a result of a call to estinterval
confidence level for identifying intervals as fundamental
logical atomic vector of the same length as x$data
This functions thus determines for each interval x$data whether it has a probabiliy > conf.level to be
a fundamental interval, given the model fit generated by estinterval for object x.
The fit of an intRvals object gives the decomposition of the likelihood of an interval observation
into partial likelihoods \(\phi_{obs}(x,i | \mu, \sigma, p)\) (see intervalpdf).
If the amplitude of the partial likelihood with i=0 (i.e. the likelihood component without missed observations)
is at least a proportion conf.level of the sum of all terms i=0..N,
an interval is considered to be fundamental (not containing a missed event observation).