The dataset contains observations from two sites: the island of Schiermonnikoog (saltmarsh) and Terschelling (agricultural grassland). Brent geese were observed continuously with spotting scopes, and the time when geese excreted a dropping was written down. The time in seconds between wo subsequently observed dropping arrivals of a single individual refers to one dropping interval. The variables are as follows:
dateobservation start time of the interval
intervallength of the interval in seconds
bout_lengthtotal observation time of individual
prop_abdomen_seenproportion of total observation time when abdomen could be observed
bout_idintervals belonging to the same observation bout of an individual have the same bout_id
siteobservation site. One of 'terschelling' (agricultural grassland) or 'schiermonnikoog' (salt marsh)
periodtwo-week observation period (1-5)
goosedropAn object of class data.frame with 705 rows and 7 columns.